# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: discount/grpc/discount.proto
# Protobuf Python Version: 4.25.1
# pylint: skip-file
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1c\x64iscount/grpc/discount.proto\x12\x0f\x63onfig.discount\x1a\x1cgoogle/protobuf/struct.proto"`\n\x1e\x44iscountCalculateByItemRequest\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x05\x12\x15\n\rdiscount_type\x18\x02 \x01(\t\x12\x17\n\x0fitem_identifier\x18\x03 \x01(\t"g\n\x1f\x44iscountCalculateByItemResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"}\n\x1f\x44iscountCalculateByTokenRequest\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x05\x12\x18\n\x10token_identifier\x18\x02 \x01(\t\x12\x1c\n\x0fuser_identifier\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x12\n\x10_user_identifier"h\n DiscountCalculateByTokenResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"X\n\x10\x44iscountResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"3\n\x17\x44iscountRetrieveRequest\x12\x18\n\x10token_identifier\x18\x01 \x01(\t"e\n\x17\x44iscountValidateRequest\x12\x18\n\x10token_identifier\x18\x01 \x01(\t\x12\x1c\n\x0fuser_identifier\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x12\n\x10_user_identifier"`\n\x18\x44iscountValidateResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct2\xc5\x03\n\x12\x44iscountController\x12v\n\x0f\x43\x61lculateByItem\x12/.config.discount.DiscountCalculateByItemRequest\x1a\x30.config.discount.DiscountCalculateByItemResponse"\x00\x12y\n\x10\x43\x61lculateByToken\x12\x30.config.discount.DiscountCalculateByTokenRequest\x1a\x31.config.discount.DiscountCalculateByTokenResponse"\x00\x12Y\n\x08Retrieve\x12(.config.discount.DiscountRetrieveRequest\x1a!.config.discount.DiscountResponse"\x00\x12\x61\n\x08Validate\x12(.config.discount.DiscountValidateRequest\x1a).config.discount.DiscountValidateResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "discount.grpc.discount_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DISCOUNTCALCULATEBYITEMREQUEST"]._serialized_start = 79
    _globals["_DISCOUNTCALCULATEBYITEMREQUEST"]._serialized_end = 175
    _globals["_DISCOUNTCALCULATEBYITEMRESPONSE"]._serialized_start = 177
    _globals["_DISCOUNTCALCULATEBYITEMRESPONSE"]._serialized_end = 280
    _globals["_DISCOUNTCALCULATEBYTOKENREQUEST"]._serialized_start = 282
    _globals["_DISCOUNTCALCULATEBYTOKENREQUEST"]._serialized_end = 407
    _globals["_DISCOUNTCALCULATEBYTOKENRESPONSE"]._serialized_start = 409
    _globals["_DISCOUNTCALCULATEBYTOKENRESPONSE"]._serialized_end = 513
    _globals["_DISCOUNTRESPONSE"]._serialized_start = 515
    _globals["_DISCOUNTRESPONSE"]._serialized_end = 603
    _globals["_DISCOUNTRETRIEVEREQUEST"]._serialized_start = 605
    _globals["_DISCOUNTRETRIEVEREQUEST"]._serialized_end = 656
    _globals["_DISCOUNTVALIDATEREQUEST"]._serialized_start = 658
    _globals["_DISCOUNTVALIDATEREQUEST"]._serialized_end = 759
    _globals["_DISCOUNTVALIDATERESPONSE"]._serialized_start = 761
    _globals["_DISCOUNTVALIDATERESPONSE"]._serialized_end = 857
    _globals["_DISCOUNTCONTROLLER"]._serialized_start = 860
    _globals["_DISCOUNTCONTROLLER"]._serialized_end = 1313
# @@protoc_insertion_point(module_scope)
